package jain.application.services.jcc;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

import jain.application.services.jcp.*;
/**
    Provider of JAIN Call Control services. Note also that the JccProvider acts as 
    a Factory to create standard {@link EventFilter} objects. These 
    standard EventFilter objects should be
    provided by the JCC platform implementation.  It is hoped that these filters
    will meet the needs of many applications, thus sparing them of the need to
    implement them explicitly.  It is also possible that by implementing these 
    on the JCC platform (rather than on the application platform) that the cost 
    of remote filter queries can be eliminated thereby addressing the performance 
    problems.
    <p>    
    Hence, three standard filters and two filter combiners are proposed. 
    The effect of these three standard filters and two filter combiners is to allow
    for address ranges in combination with event "masks".  Using these methods, it is possible to create filters 
    that return a given event disposition for address in specific ranges (with holes
    and overlaps), or for specific events, or a combination of both.  
    It is also possible to make filters that combine standard and custom filters. 
    This would make it possible to quickly determine the filter disposition in many
    common cases, using standard filters, and only call a custom filter is unusual 
    cases. We later look at each of these standard filters individually. 

<h5>Event Snapshots</h5>

By default, when a {@link JcpProviderListener} is added through {@link #addProviderListener(JcpProviderListener)},
the first batch of events may be a "snapshot".
That is, if the listener was added after state changes in the Provider, the first batch of events will inform the
application of the current state of the Provider. Note that these snapshot events do NOT provide a history
of all events on the Provider, rather they provide the minimum necessary information to bring the application
up-to-date with the current state of the Provider. 
 
 */
public interface JccProvider extends JcpProvider
{

   /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This method  takes two arrays of eventID integers (values returned from {@link JcpEvent#getID()}).  
    For event IDs in the blockEvents array, the filter returns {@link EventFilter#EVENT_BLOCK}.
    For event IDs in notifyEvents, the filter returns {@link EventFilter#EVENT_NOTIFY}.
    If any event ID is not listed in one of the two arrays, the filter returns 
    {@link EventFilter#EVENT_DISCARD}.
    The application is supposed to ensure that  an event ID is not 
    listed in more than one array. If done, the filter may return any one 
    of the listed event dispositions.  
    @parameter blockEvents is an array containing the list of events for which the application 
    wants to be notified with the call processing blocked.
    @parameter notifyEvents is an array containing the list of events for which the application 
    wants to be notified without the call processing being blocked.
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.
    @throws ResourceUnavailableException An internal resource for completing this
    call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    
    */
    
    public EventFilter createEventFilterEventSet(int blockEvents[], int notifyEvents[]) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each address in the call obtained by {@link JcpCallEvent#getCall()}, apply the following.
    If the address is between lowAddress and highAddress (inclusive), the filter 
    returns the value matchDisposition. 
    If the address is not in the range specified, then return nomatchDisposition. 
    
    @param lowAddress denotes the JcpAddress which corresponds to the low end of the 
    range. 
    @param highAddress denotes the JcpAddress which corresponds to the high end of the 
    range. 
    @param matchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which forms part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which DOES not form part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
        @throws ResourceUnavailableException An internal resource for completing this
        call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */

    public EventFilter createEventFilterAddressRange(String lowAddress, String highAddress, int matchDisposition, int nomatchDisposition) throws
    ResourceUnavailableException, InvalidArgumentException;
    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each address in the call obtained by {@link JcpCallEvent#getCall()}, apply the following.
	Obtain a string using address.getName().
    If this string matches the regular expression addressRegex, the filter returns 
    the value matchDisposition. For the purpose of this specification, the platform 
    will use the Perl5 regular expressions. 
    If no such addresses are matched, then return nomatchDisposition.

    @param addressRegex denotes the regular expression. 
    @param matchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress matches the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress DOES not match the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
    @throws ResourceUnavailableException An internal resource for completing this
    call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */

    public EventFilter createEventFilterAddressRegEx(String addressRegex, int matchDisposition, int nomatchDisposition) throws
    ResourceUnavailableException,InvalidArgumentException ;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This filter takes as input an array of EventFilters.
    For a given event, it applies the filters in order.  
    If a filter returns nomatchDisposition, then the next filter is tested.  
    If a filter returns any other disposition, then the filter returns this value and 
    does no further filter evaluation.
    This would normally be called with nomatchDisposition set to {@link EventFilter#EVENT_DISCARD} to 
    process any event (either by notifying or blocking) that any filter wants to 
    process (logical OR).
    @param filters is an array of EventFilters. 
    @param nomatchDisposition indicates the disposition of a JCC related event.
    This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
        @throws ResourceUnavailableException An internal resource for completing this
        call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid

    */

    public EventFilter createEventFilterOr(EventFilter filters[], int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;
     
    /**    
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This filter takes as input an array of EventFilters.
    For a given event, it applies the filters in order. 
    If the values returned from all filters are the same, then this value is returned 
    as the filter value.
    Otherwise, the filter returns nomatchDisposition.
    This means that as soon as any filter returns nomatchDisposition, or as soon as
    two filters return different values, the filter can immediately return 
    nomatchDisposition.
    This would normally be called with nomatchDisposition set to {@link EventFilter#EVENT_DISCARD} to 
    discard any events that any filter wants to discard (logical AND).    
    @param filters is an array of EventFilters. 
    @param nomatchDisposition indicates the disposition of a JCC related event.
    This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
        @throws ResourceUnavailableException An internal resource for completing this
        call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
     */
    public EventFilter createEventFilterAnd(EventFilter filters[],int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each originating connection, apply the following.
	Obtain a string using getDestinationAddress().
    If the destination 
    address is between lowDestAddress and highDestAddress (inclusive), the filter returns the value matchDisposition. 
    If the address is not in the specified range or the filter is not operating on an originating connection, then return nomatchDisposition. 
    
    @param lowDestAddress denotes the destination JcpAddress which corresponds to the low end of the 
    range. 
    @param highDestAddress denotes the destination JcpAddress which corresponds to the high end of the 
    range. 
    @param matchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which forms part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which DOES not form part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
        @throws ResourceUnavailableException An internal resource for completing this
        call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */
	public EventFilter createEventFilterDestAddressRange(String lowDestAddress, String highDestAddress, int matchDisposition, int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each originating connection, apply the following.
	Obtain a string using getDestinationAddress():
    If this string matches the regular expression destAddressRegex, the filter returns 
    the value matchDisposition. For the purpose of this specification, the platform 
    will use the Perl5 regular expressions. 
    If no such addresses are matched or the filter is not operating on an originating connection, then return nomatchDisposition. 

    @param destAddressRegex denotes the regular expression for the destination address. 
    @param matchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress matches the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress DOES not match the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
    @throws ResourceUnavailableException An internal resource for completing this
    call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */
	public EventFilter createEventFilterDestAddressRegEx(String destAddressRegex, int matchDisposition, int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each destination connection, apply the following.
	Obtain a string using getOriginatingAddress().getName().
    If the destination 
    address is between lowOrigAddress and highOrigAddress (inclusive), the filter returns the value matchDisposition. 
    If the address is not in the specified range or the filter is not operating on a terminating connection, then return nomatchDisposition. 
    
    @param lowOrigAddress denotes the originating JcpAddress which corresponds to the low end of the 
    range. 
    @param highOrigAddress denotes the originating JcpAddress which corresponds to the high end of the 
    range. 
    @param matchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which forms part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event occurring on a
    JcpAddress which DOES not form part of the range specified. This should be one of the legal
    dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
        @throws ResourceUnavailableException An internal resource for completing this
        call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */
	public EventFilter createEventFilterOrigAddressRange(String lowOrigAddress, String highOrigAddress, int matchDisposition, int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
    This method returns a standard EventFilter which is implemented by the JCC platform.
    This requires a complete ordering of values in JcpAddress.  The ordering is arranged 
    by defining the order to be by {@link JcpAddress#getName()}'s string order.
    For each originating connection, apply the following.
	Obtain a string using getOriginatingAddress().getName():
    If this string matches the regular expression origAddressRegex, the filter returns 
    the value matchDisposition. For the purpose of this specification, the platform 
    will use the Perl5 regular expressions. 
    If no such addresses are matched or the filter is not operating on a terminating connection, then return nomatchDisposition. 

    @param origAddressRegex denotes the regular expression for the originating address. 
    @param matchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress matches the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @param nomatchDisposition indicates the disposition of a JCC related event if the 
    name of the JcpAddress DOES not match the regular expression. This should be one of the 
    legal dispositions namely, {@link EventFilter#EVENT_BLOCK}, {@link EventFilter#EVENT_DISCARD} or {@link EventFilter#EVENT_NOTIFY}. 
    @return EventFilter standard EventFilter provided by the JCC platform to enable 
    filtering of events based on the application's requirements.    
    @throws ResourceUnavailableException An internal resource for completing this
    call is unavailable. 
    @throws InvalidArgumentException One or more of the provided argument is not valid
    */
	public EventFilter createEventFilterOrigAddressRegEx(String origAddressRegex, int matchDisposition, int nomatchDisposition) throws 
    ResourceUnavailableException, InvalidArgumentException;

    /**
       Add a call listener to all (future and current) call objects within the domain
       of this provider.  If the listener is added to existing calls, the listener will receive 
       <a href="../jcp/JcpCall.html#event_snapshots">event snapshots</a>.
       The listener added with this method will
       receive events on the call for as long as the implementation can 
       listen to  the Call. In the case that the implementation can no
       longer observe the JcpCall, the listeners receives a 
       {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}.
       The listener receives no more events after it receives the 
       {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}. 

        <H5>Listener Lifetime</H5> 
        The <CODE>JcpCallListener</CODE> will 
        receive events until one of the following occurs, whereupon the 
        listener receives a {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}.
        <OL> 
        <LI>The listener is removed by the application. 
        <LI>The implementation can no longer monitor the call. 
        <LI>The JcpCall has completed and moved into the {@link JcpCall#INVALID} state.
        </OL> 
        
       <H5>ConnectionListeners</H5> 
        Since {@link JcpConnectionListener} inherits from the JcpCallListener, it is also 
        possible to add a JcpConnectionListener using this method. In such a case, 
        connection events  would also have to be reported to the
        registered listener in addition to the call events. 
        Hence, it is expected that the JCC implementation uses instanceof checks 
        in order to decide if only call events or both call and connection events 
        have to be delivered to the listener. Note that a listener added by this 
        method is expecting all the events without any filtering involved. 
        
        <H5>Multiple Invocations</H5> 
        If an application attempts to add an
        instance of an listener already present on this Call, then a repeated 
        invocation will 
        silently fail, i.e. multiple instances of an listener are not added
        and no exception will be thrown.
        
       @param calllistener JcpCallListener object that receives the specified events.
       @throws MethodNotSupportedException The method is not supported.
       @throws ResourceUnavailableException The resource limit for the number of 
       listeners has been exceeded. 
       <br>
    */

    public void addCallListener( JcpCallListener calllistener ) throws MethodNotSupportedException, 
    ResourceUnavailableException;

    /**
       Add a call listener to all (future and current) call objects within the domain
       of this provider.  The listener added with
       this method will
       report events on the call for as long as the implementation can 
       listen to  the Call. In the case that the implementation can no
       longer observe the Call, the applications receive a {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}.
       The listener receives
       no more events after it receives the {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}. 
        This method behaves identically to the method 
        {@link #addCallListener( JcpCallListener)} when the filter returns
        a {@link EventFilter#EVENT_NOTIFY} for all the events of interest. 
  
  
        <H5> Connection Events </H5>
        A JccConnectionEvent extends JccCallEvent and a JccConnectionListener extends
        JccCallListener. Hence, a JccConnectionListener can also be added using this
        method. In such a case, events on the JccConnection objects associated with this
        JccCall object might have to be reported to the registered listener after
        consulting with the EventFilter. 
        In summary  
        the implementation must distinguish between JccCallListener 
         and JccConnectionListener in order to  determine the events for which 
         the implementation must consult the corresponding EventFilter. 
 
        
        <H5>Listener Lifetime</H5> 
        The <CODE>CallListener</CODE> will 
        receive events until one of the following occurs, whereupon the 
        listener receives a {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}. <p> 
        <OL> <LI>The listener is removed by the application. 
        <LI>The implementation 
        can no longer monitor the call. 
        <LI>The Call has completed and 
        moved into the  {@link JcpCall#INVALID} state. </OL> 
        <H5>Multiple Invocations</H5> 
        If an application attempts to add an
        instance of an listener already present on this Call, then a repeated 
        invocation will 
        silently fail, i.e. multiple instances of an listener are not added
        and no exception will be thrown. This though results in the filter being 
        added in the last invocation being used by the implementation to filter events.
        
       @param calllistener JccCallListener object that receives the specified events.
       @param filter EventFilter that determines if an event should be delivered 
       to the registered JcpCallListener. 
       @throws MethodNotSupportedException The method is not supported.
       @throws ResourceUnavailableException The resource limit for the number of 
       listeners has been exceeded. 
       <br>
     */
    public void addCallListener( JccCallListener calllistener,EventFilter filter )  throws ResourceUnavailableException, 
    MethodNotSupportedException;

    /**
        Removes a call listener that was previously registered.
        The given listener will no longer receive events generated by the Call objects on this Provider.
        A JcpConnectionListener can also be removed using this method. 
        Note that the listeners will stop receiving events for existing calls also. 
        
       Also, if the listener is not currently registered with the Provider, then this 
       method fails silently, i.e. no listener is removed and no exception is thrown.<p>

        <B>Post-Conditions:</B> <OL>
        <LI>CALL_EVENT_TRANSMISSION_ENDED is delivered to the application.  
        </OL>

       @param calllistener JcpCallListener object to be removed.
     */
    public void removeCallListener( JcpCallListener calllistener );

    /**
       Add a connection listener to all connections under this JcpProvider.
       This method
       behaves similar to the addCallListener(conListener, filter) method 
       on this interface where conListener is in fact a JccConnectionListener. 
       When conListener is not a JccConnectionListener but is only a JccCallListener, 
       a similar behavior as addCallListener(conListener, newfilter)
       can be obtained with this method using a JccConnectionListener and a 
       different EventFilter which filters
       all the JccConnection related events in addition to the events being filtered
       by newfilter. 
       Note though that using this method only 
       JccConnectionListeners can be added. 
       <p>

       Note that registering for the same event multiple times should not
       result in multiple notifications being sent to an application for
       the same event. Rather, this will result in the last event
       filter being used to determine if events have to be delivered to the
       specified ConnectionListener. 
       <p>
       
       Note that this method is also equivalent to 
       <a href="#addCallListener(JccCallListener,EventFilter)">addCallListener(JccConnectionListener,EventFilter)</A>. 
       since parameter JcpConnectionListener is also a JcpCallListener. However note that
       JcpCallListeners which are not JcpConnectionListeners cannot be used as a parameter
       to this method.

       @param connectionlistener JccConnectionListener object that receives the specified events.
       @param filter EventFilter determines if the ConnectionEvent is 
       to be delivered to the specified listener. 
       @throws MethodNotSupportedException The listener cannot be added at this time.
       @throws ResourceUnavailableException The resource limit for the number of 
       listeners has been exceeded. 
       

     */
    public void addConnectionListener( JccConnectionListener connectionlistener, EventFilter filter)throws ResourceUnavailableException, 
    MethodNotSupportedException;;

    /**
        Removes a connection listener that was registered previously.
        The given listener will no longer
       receive events generated by the JcpConnection objects related to this JcpProvider object through a JcpCall object.
       Also, if the listener is not currently registered with the JcpProvider, then this 
       method fails silently, i.e. no listener is removed and no exception is thrown.

        <p><B>Post-Conditions:</B> <OL>
        <LI>CALL_EVENT_TRANSMISSION_ENDED is delivered to the application.  
        </OL>

       @param connectionlistener JcpConnectionListener object used in the call to addConnectionListener method.
     */
    public void removeConnectionListener( JcpConnectionListener connectionlistener);
    /**
     This method imposes or removes load control on calls made to the specified addresses.
        <p>
       The implementation can throw the {@link MethodNotSupportedException} if the 
       platform does not support the load control functionality. <em> Note </em>  that a policy 
       object may be designed to define the policy to be implemented by the platform 
       as a result of this method instead of defining the policy through the given 
       parameters. This might be designed in the future specifications.

       @param address An array of size at most 2. a1[0] denotes the lower
       address of the range while a1[1] denotes the uper address of the range.
       Specifying only one element of the array implies that only an individual address
       is no longer to be the subject of the listener's attention. This constrains the range of addresses
       added to be numerical addresses. For addresses containing non-numerals such as 
       email addresses, we expect that the application would have to add each address
       individually. Note that it is expected that adding a range of non-numerical addresses
       efficiently will be addressed in a future version of this specification.
       @param duration specifies the duration in milliseconds for which the load control should be set. Duration
       of 0 indicates that the load control should be removed. Duration of -1 indicates
       an infinite duration (i.e until disabled by the application). Duration of -2 
       indicates network default duration. 
       @param mechanism specifies the load control mechanism to use (such as admitting one call
       per interval) and any necessary parameters. The contents of this parameter are 
       ignored if the load control duration is set to zero.mech[0] symbolises the call
       admission rate of the call load control mechanism used. mech[1] symbolises the 
       type of call load control mechanism to use. Thus, mech[0] gives the number
       of calls to be admitted per interval and mech[1] denotes the interval (in 
       milliseconds) between calls that are admitted.
       @param treatment specifies the treatment of the calls that are not admitted.The contents of this parameter are 
       ignored if the load control duration is set to zero.
       @throws MethodNotSupportedException If the implementation does not 
       have load control functionality. 
    */    
    public void setCallLoadControl(JccAddress[] address, double duration, double[] mechanism,int[] treatment)
        throws MethodNotSupportedException;

    /**
       Adds a listener to listen to load control related events. Note that the load control
       functionality has to have been specified separately using {@link #setCallLoadControl(JccAddress[],double,double[],int[])}
       method.  
       @param loadcontrollistener The listener implementing the {@link CallLoadControlListener} interface which will
       receive all load control related events. 
       @param filter EventFilter which specifies if the {@link CallLoadControlEvent}
       is to be delivered to the specified CallLoadControlListener. 
       @throws MethodNotSupportedException The listener cannot be added at this time.
       @throws ResourceUnavailableException The resource limit for the number of 
       listeners has been exceeded. 
    */
    public void addCallLoadControlListener(CallLoadControlListener loadcontrollistener, EventFilter filter) throws
    MethodNotSupportedException, ResourceUnavailableException;
    
    /**
       Deregisters the load control listener. This results in the listener not receiving
       any load control related events in the future. Note that if loadcontrollistener is not already 
       registered using the {@link #setCallLoadControl(JccAddress[],double,double[],int[])} method then this method 
       fails silently. 
       @param loadcontrollistener The listener implementing the CallLoadControlListener interface which will
       receive all load control related events
    */
    public void removeCallLoadControlListener(CallLoadControlListener loadcontrollistener);

}

