package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
<P>An <CODE>JcpAddress</CODE> object represents what we commonly think of 
as a "telephone number". 

<H4>Introduction</H4> 
An address uniquely identifies a communication endpoint--physical or logical. 
Its string representation is obtained by the method {@link #getName()}. 

<p> Address objects may be classified into two categories: 
<EM>local</EM> and <EM>remote</EM>.
A "Local"
Address is one physically or administratively serviced by the existing
Provider. Conversely, a "Remote" address is not served by this Provider. 
A remote Address may not have the full visibility or control capabilities
of a local address. (By impaired visibility, we mean connection states
involving this address may not be as finely discriminated; by impaired
control, we mean that not all the connection's methods involving this 
address may be functional.)
 Note that applications never explicitly create 
new Address objects. 

<H4>Address and Call Objects</H4> 
Address objects are related to Call objects via the Connection
object. The Connection object has a <EM>state</EM> which describes 
the current relationship between the Call and the Address. Each Address 
object may be part of more than one telephone call, and in each case,
is represented by a separate Connection object. 
<p> 

An Address is associated with a Call until the Connection moves into
the {@link JcpConnection#DISCONNECTED} state. 

*/
public interface JcpAddress
{
    /**
    Returns the string representation of the JcpAddress. Note that  
    each JcpAddress possesses a unique string representation within a 
    given JcpProvider.  
    
    @return the "unique" string representation of this JcpAddress.
    */
    public String getName();
    /**
        Retrieves the Jcpprovider handling this address object. This JcpProvider
        object is valid throughout the lifetime of the JcpAddress and does 
        not change once the JcpAddress is created. 

        @return JcpProvider object managing this call.
    */
    public JcpProvider getProvider();

}
 
