package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
    This is the base interface for all JcpCall-related events. Events which extend this interface
    are reported via methods on the {@link JcpCallListener} interface.                   
    
    */
public interface JcpCallEvent extends JcpEvent
{
    /**
        Returns the JcpCall object associated with this event.

    @return JcpCall represents the JcpCall object associated with this JcpCall event. The result of this call might be a cast of the result of {@link JcpEvent#getSource()}.
    */
    public JcpCall getCall(  );

    /**
        The CALL_ACTIVE event 
        indicates that the state of the Call object has changed to {@link JcpCall#ACTIVE}.
        <br>
        This constant corresponds to a specific call state change, is passed via a 
        JcpCallEvent event and is reported to the {@link JcpCallListener#callActive(JcpCallEvent)} method.
    */
    public static int CALL_ACTIVE         = 101;

    /**
        The CALL_INVALID event 
        indicates that the state of the JcpCall object has changed to {@link JcpCall#INVALID}.
        <br>
        This constant corresponds to a specific call state change, is passed via a 
        JcpCallEvent event and is reported to the {@link JcpCallListener#callInvalid(JcpCallEvent)} method.
    */
    public static int CALL_INVALID        = 102;
    /**
         The CALL_EVENT_TRANSMISSION_ENDED
         event indicates that the application will no longer receive JcpCall events  on 
         the instance of the JcpCallListener. 
        <br>
        This constant corresponds to a specific call state change, is passed via a 
        JcpCallEvent event and is reported to the {@link JcpCallListener#callEventTransmissionEnded(JcpCallEvent)} method.
    */
    public static int CALL_EVENT_TRANSMISSION_ENDED = 103;
    /**
        The CALL_CREATED event 
        indicates that the JcpCall object has been created and is in the 
        {@link JcpCall#IDLE} state.
        <br>
        This constant corresponds to a specific call state change, is passed via a 
        JcpCallEvent event and is reported to the {@link JcpCallListener#callCreated(JcpCallEvent)} method.
    */
    public static int CALL_CREATED        = 118;
    
    
}

