package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
<H4>Introduction</H4> 
The purpose of a JcpConnection object is to describe 
the relationship between a {@link JcpCall} object and a {@link JcpAddress} object.
A JcpConnection object exists if the JcpAddress is a part of the telephone call.
Each JcpConnection has a <EM>state</EM> which describes the particular stage
of the relationship between the JcpCall and JcpAddress. These states and their
meanings are described below. Applications use the 
{@link #getCall()} and {@link #getAddress()}
methods to obtain the JcpCall and JcpAddress associated with this JcpConnection,
respectively. <p>

From one perspective, an application may view a JcpCall 
only in terms of the JcpAddress/JcpConnection objects which are part of the 
JcpCall. This is termed a <EM>logical</EM> view of the Call.  In this 
logical view, a telephone
call is viewed as two or more endpoint addresses in communication. The 
JcpConnection object describes the state of each of these endpoint addresses
with respect to the JcpCall. 

<H4>JcpCalls and JcpAddresses</H4>
JcpConnection objects
are immutable in terms of their JcpCall and JcpAddress references. In other 
words, the JcpCall and JcpAddress object references do not change throughout 
the lifetime of the JcpConnection object instance. The same JcpConnection 
object may not be used in another telephone call. The existence of a 
JcpConnection implies that its JcpAddress is associated with its JcpCall in the 
manner described by the JcpConnection's state. <p>

Although a JcpConnection's
JcpAddress and JcpCall references remain valid throughout the lifetime of the
JcpConnection object, the same is not true for the JcpCall and JcpAddress object's
references to this JcpConnection.
Particularly, when a  JcpConnection moves into
the {@link #DISCONNECTED} state, it is no longer listed by the 
{@link JcpCall#getConnections()} method. 
Typically, when a JcpConnection moves into the
<CODE>DISCONNECTED</CODE> state, the application loses its 
references to it to facilitate its garbage collection. 

 <H4>Connection States</H4>
 Below is a description of each JcpConnection state in 
 real-world terms. These real-world descriptions have no bearing on the
 specifications of methods, they only serve to provide a more intuitive 
 understanding of what is going on. Several methods in this specification
 state pre-conditions based upon the state of the Connection.<p> 
 
 <TABLE CELLPADDING=2> <TR> <TD WIDTH="15%">
 {@link #IDLE}</TD> <TD WIDTH="85%"> 
 This state is the initial state for all new Connections. Connections 
 which are in the <CODE>IDLE</CODE> state are not actively 
 part of a telephone call, yet their references to the Call and Address 
 objects are valid. Connections typically do not stay in the 
 <CODE>IDLE</CODE> state for long, quickly transitioning to 
 other states. </TD> </TR> <TR> <TD WIDTH="15%">
 
 {@link #DISCONNECTED}</TD> <TD WIDTH="85%"> This state 
 implies it is no longer part of the telephone call, although its 
 references to Call and Address still remain valid. A Connection in this
 state is interpreted as once previously belonging to this telephone call.
 </TD> </TR> <TR> <TD WIDTH="15%">
 
 {@link #INPROGRESS}</TD>
 <TD WIDTH="85%"> This state implies that the JccConnection object 
 has been contacted by the origination  side or is contacting the destination side.
 The contact happens as a result of the underlying protocol messages. 
 Under certain circumstances, the 
 Connection may not progress beyond this state. Extension packages 
 elaborate further on this state in various situations. </TD> </TR> 
 <TR> <TD WIDTH="15%">{@link #ALERTING}</TD>
 <TD WIDTH="85%"> This state implies that the Address is being notified 
 of an incoming call. </TD> </TR> <TR> <TD WIDTH="15%">
 
 {@link #CONNECTED}</TD> <TD WIDTH="85%"> This state 
 implies that a Connection and its Address is actively part of a
 telephone call. In common terms, two people talking to one another are
 represented by two Connections in the <CODE>CONNECTED</CODE>
 state. </TD> </TR> <TR> <TD WIDTH="15%">
 
 {@link #UNKNOWN}</TD> <TD WIDTH="85%"> This state implies that the implementation is 
 unable to determine the current state of the Connection. Typically, 
 methods are invalid on Connections which are in this state. Connections 
 may move in and out of the <CODE>UNKNOWN</CODE> state at any 
 time. </TD> </TR> <TR> <TD WIDTH="15%">
 
 {@link #FAILED}</TD> <TD WIDTH="85%"> This state indicates that a Connection to that 
 end of the call has failed for some reason. One reason why a Connection 
 would be in the <CODE>FAILED</CODE> state is because the 
 party was busy. Connections that are in the <code>FAILED</code> state are still connected to the call.
 </TD> </TR> </TABLE> 
 
 <H4>Connection State Transitions</H4> 
 *
 * Consider the transitions given below as the ones that would be visible to the application 
 * developer in the package considered. This may be either because there is a method in that 
 * class/interface that provides that behavior (read transition) or because of events in the 
 * underlying platform. Note that we are not making any statements to the effect that the other 
 * transitions (ones not shown) are disallowed. The application developer would have to keep 
 * in mind the possibility that the "invisible" transitions can surface (become visible) in 
 * inherited classes/interfaces.
 <P> 
 
 Note there is a general left-to-right
 progression of the state transitions. A JcpConnection object may transition
 into and out of the {@link #UNKNOWN} state at any time 
 (hence, the asterisk qualifier next to its bidirectional transition 
 arrow).
 
 <CENTER>
 <H1>JcpConnection FSM</H1>
 <IMG SRC="doc-files/core-connectionstates.gif" ALIGN="center"> 
 </CENTER>
 
 <H4>Listeners and Events</H4> 
All events pertaining to the JcpConnection object are reported via the 
{@link JcpCallListener} interface on the JcpCall object associated with
this JcpConnection. Events are reported to a 
JcpCallListener when a new JcpConnection is created and whenever a JcpConnection 
changes state.

*/
public interface JcpConnection
{
    /**
        Retrieves the state of the JcpConnection object. 

        @return Integer representing the state of the call.
        See static int's defined in this object.
     */
    public int getState();
    /**
        Retrieves the Jcpcall that is associated with this JcpConnection. This 
        JcpCall reference remains valid throughout the lifetime of the JcpConnection 
        object despite the state of the JcpConnection object. This JcpCall 
        reference does not change once the JcpConnection object has been 
        created. 

        @return JcpCall object holding this connection.
    */
    public JcpCall getCall();

    /**
    Returns the JcpAddress associated with this JcpConnection. This JcpAddress 
    object remains valid throughout the lifetime of the JcpConnection 
    object despite the state of the JcpConnection object. This JcpAddress 
    reference does not change once the JcpConnection object has been 
    created. 

    @return JcpAddress object associated with this JcpConnection object.
    */
    public JcpAddress getAddress();

    /**
        The <CODE>JcpConnection.DISCONNECTED</CODE> state implies it is no 
        longer part of the telephone call, although its references to Call and 
        Address still remain valid.<p>
         
        <em> Entry criteria: </em> This state 
        is entered when a disconnect indication is received from the 
        corresponding party or the application.<br>
        
        <em> Function: </em> The (bearer) connection to the party
        is disconnected and depending on the incoming network connection, appropriate
        backward signaling takes place. <br>
        
        <em> Exit criteria: </em> 
    */
    public static final int DISCONNECTED              = 0;
    
        /**
        The <CODE>JcpConnection.IDLE</CODE> state is the initial state for all 
        new JcpConnection objects.
         A JcpConnection object in the 
        IDLE state while not yet actively participating in a call can 
        still reference a JcpCall and JcpAddress object. <p>
        
        <em>Entry criteria  </em>  Start of a new call.           <br>
        
        <em> Functions: </em> Interface (line/trunk) is idled. <br>
        
        <em> Exit criteria: </em> An indication of the desire to place an outgoing
        call or when the indication of an incoming call is received.  
                       
    */
    public static final int IDLE                      = 1;


    /**
        The <CODE>JcpConnection.ALERTING</CODE> state implies that the Address is
        being notified of an incoming call.
         
        <p>
        <em> Entry criteria: </em> This state 
        is entered when the terminating party is being alerted of an incoming 
        call. <br>
        
        <em> Function: </em> An indication is sent to the originating party that the terminating 
        party is being alerted.<br>
        
        <em> Exit criteria: </em> This state is exited when the call is accepted
         and answered by the terminating party. Exception criteria such as 
         callrejected, NoAnswer and Abandon if possible all cause exit 
         from this state.                 
    */
    public static final int ALERTING                  = 6;

    /**
        The <CODE>JcpConnection.CONNECTED</CODE> state implies that 
        originating and terminating connection objects and the associated 
        Address objects are actively part of a call.   <p>
        
        <em> Entry criteria: </em> This state is entered 
        when the Call is accepted and answered by the terminating party.<br>
        
        <em> Function: </em> In this state several processes related to 
        message accounting/charging, call supervision etc. may be initiated
         if such a capability is provided by the implementation. <br>
         
        <em> Exit criteria: </em> Exception 
        criteria such as disconnect (and suspend for JCC) cause exit from this state.
    */
    public static final int CONNECTED                 = 7;

    /**
        The <CODE>JcpConnection.FAILED</CODE> state indicates that a Connection 
        to that end of the call has failed for some reason.
        One
        reason why a JcpConnection would be in the FAILED state is due to the 
        fact that the party was busy. Connections that are in the <code>FAILED</code> 
        state are still connected to the call.<p>
        
        <em> Entry criteria: </em> This state is entered when an exception condition 
        is encountered. <br>
        
        <em> Function: </em> Default handling of the exception condition is provided. <br>
        
        <em> Exit criteria: </em> Default handling of the exception condition by 
        the implementation is completed.
    */
    public static final int FAILED                    = 9;
    /**
        The <CODE>JcpConnection.UNKNOWN</CODE> state implies that the 
        implementation is unable to determine the current state of the 
        Connection. This indicates that the 
        platform does not know of the current state of the corresponding
        JccConnection object. 
    */
    public static final int UNKNOWN                    = 10;

    /**
        The <CODE>JcpConnection.INPROGRESS</CODE> state implies that the 
        JccConnection object 
        has been contacted by the origination  side or is contacting the destination side.
        The contact happens as a result of the underlying protocol messages. 
        Under certain circumstances, the 
        Connection may not progress beyond this state. Extension packages 
        elaborate further on this state in various situations.    */
    public static final int INPROGRESS                 = 11;

}

