package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
    This is the base interface for all {@link JcpProvider} related events. All events 
    which pertain to the JcpProvider object must extend this interface. Events
    which extend this interface are reported via the {@link JcpProviderListener} interface. 
*/
public interface JcpProviderEvent extends JcpEvent
{
    /**
    returns the JcpProvider associated with this JcpProvider Event. The result of this call might be a cast of the result of {@link JcpEvent#getSource()}.
    @return The JcpProvider associated with this event. 
    */
    public JcpProvider getProvider();
    /**
         This indicates that the
        state of the JcpProvider object has changed to {@link JcpProvider#IN_SERVICE}. 
        This constant 
        indicates a specific event passed via a JcpProviderEvent event and is reported on the
        JcpProviderListener interface.
    */
    public static final int PROVIDER_IN_SERVICE     = 119;

    /**
         This also indicates that the
        state of the JcpProvider object has changed to {@link JcpProvider#OUT_OF_SERVICE}.
        This constant 
        indicates a specific event passed via a JcpProviderEvent event and is reported on the
        JcpProviderListener interface.
    */
    public static final int PROVIDER_OUT_OF_SERVICE = 120;

    /**
        This also indicates that the
        state of the JcpProvider object has changed to {@link JcpProvider#SHUTDOWN}.
        This constant 
        indicates a specific event passed via a JcpProviderEvent event and is reported on the
        JcpProviderListener interface.
    */
    public static final int PROVIDER_SHUTDOWN = 121;
    /**
        indicates that the application will no longer receive JcpProvider Events.
        This constant 
        indicates a specific event passed via a JcpProviderEvent event and is reported on the
        JcpProviderListener interface.
    */
    public static final int PROVIDER_EVENT_TRANSMISSION_ENDED = 122;
}
