package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
    Interface for notifying changes happening in a {@link JcpProvider}. These changes are
    reported as events to the {@link JcpProviderListener} method corresponding to the type of event.
    Applications must instantiate an object which implements this interface and then use
    the {@link JcpProvider#addProviderListener(JcpProviderListener)} method to register the object 
    to receive all future events associated with the JcpProvider object.
*/
public interface JcpProviderListener extends java.util.EventListener
{
    /**
        Indicates that the state of the JcpProvider has changed to {@link JcpProvider#IN_SERVICE}.

        @param providerevent JcpProviderEvent with event ID JcpProviderEvent.PROVIDER_IN_SERVICE.
    */
    public void providerInService( JcpProviderEvent providerevent );

    /**
        Indicates that the state of the JcpProvider has changed to {@link JcpProvider#OUT_OF_SERVICE}.

        @param providerevent JcpProviderEvent with event ID JcpProviderEvent.PROVIDER_OUT_OF_SERVICE.
    */
    public void providerOutOfService( JcpProviderEvent providerevent );

    /**
        Indicates that the state of the JcpProvider has changed to {@link JcpProvider#SHUTDOWN}.

        @param providerevent JcpProviderEvent with event ID JcpProviderEvent.PROVIDER_SHUTDOWN.
    */
    public void providerShutdown( JcpProviderEvent providerevent );
    /**
        Indicates that the application will no longer receive JcpProvider events on the 
        instance of the JcpProviderListener.

        @param providerevent JcpProviderEvent with event ID JcpProviderEvent.PROVIDER_EVENT_TRANSMISSION_ENDED.
    */
    public void providerEventTransmissionEnded( JcpProviderEvent providerevent );
}
